"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const passport = require("passport");
const passport_google_oauth_1 = require("passport-google-oauth");
const passport_http_1 = require("passport-http");
const passport_jwt_1 = require("passport-jwt");
const passport_local_1 = require("passport-local");
const _1 = require(".");
const user_model_1 = require("../models/user-model");
const user_util_1 = require("./../utils/user-util");
exports.initPassport = () => {
    passport.serializeUser((user, done) => {
        return done(null, user.id);
    });
    passport.deserializeUser((id, done) => {
        user_model_1.User.findById(id)
            .then(user => {
            return done(null, !!user ? user : false);
        })
            .catch(err => {
            return done(err, false);
        });
    });
    passport.use('local-plugin', new passport_local_1.Strategy(function (username, password, done) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user = yield user_model_1.User.findOne({ where: { username } });
                if (!user) {
                    return done(null, false, { message: 'Incorrect username.' });
                }
                const isValid = yield user_util_1.comparePassword(user, password);
                if (!isValid) {
                    return done(null, false, { message: 'Incorrect password.' });
                }
                return done(null, user);
            }
            catch (error) {
                return done(error);
            }
        });
    }));
    passport.use('basic-plugin', new passport_http_1.BasicStrategy(function (username, password, done) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user = yield user_model_1.User.findOne({ where: { username } });
                if (!user) {
                    return done(null, false);
                }
                const isValid = yield user_util_1.comparePassword(user, password);
                if (!isValid) {
                    return done(null, false);
                }
                return done(null, user);
            }
            catch (error) {
                return done(error);
            }
        });
    }));
    passport.use('google-plugin', new passport_google_oauth_1.OAuth2Strategy({
        clientID: '21905509934-bgp1qmk243hion1mt5s4qub52a7766on.apps.googleusercontent.com',
        clientSecret: 'TERflqKZSonnY6iEcZBvGTJl',
        callbackURL: 'http://localhost:8080/auth/google/callback'
    }, function (accessToken, refreshToken, profile, done) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const username = profile.id;
                // TODO: use findOrCreate
                const user = yield user_model_1.User.findOne({ where: { username } });
                if (user) {
                    return done(null, user);
                }
                const createdUser = yield user_model_1.User.create({
                    username,
                    password: 'no_password'
                });
                return done(null, createdUser);
            }
            catch (error) {
                return done(error, false);
            }
        });
    }));
    passport.use('jwt-plugin', new passport_jwt_1.Strategy({
        jwtFromRequest: passport_jwt_1.ExtractJwt.fromAuthHeaderAsBearerToken(),
        secretOrKey: _1.JWT_SECRET,
        passReqToCallback: true
    }, function (req, jwtPayload, done) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user = yield user_util_1.findUserByPayload(jwtPayload);
                if (user) {
                    return done(null, user, { jwtPayload });
                }
                return done(null, false);
            }
            catch (error) {
                return done(error);
            }
        });
    }));
};
exports.default = passport;
//# sourceMappingURL=passport.js.map