"use strict";
require("express-gateway");
const config_1 = require("./config");
const db_1 = require("./config/db");
const passport_1 = require("./config/passport");
const index_1 = require("./middleware/index");
const auth_secure_policy_1 = require("./policies/auth-secure-policy");
const basic_auth_policy_1 = require("./policies/basic-auth-policy");
const jwt_auth_policy_1 = require("./policies/jwt-auth-policy");
const local_auth_policy_1 = require("./policies/local-auth-policy");
const session_auth_policy_1 = require("./policies/session-auth-policy");
const auth_eg_1 = require("./routes/auth-eg");
const auth_user_eg_1 = require("./routes/auth-user-eg");
const google_oauth20_eg_1 = require("./routes/google-oauth20-eg");
const plugin = {
    version: '1.3.0',
    init: pluginContext => {
        config_1.initConfig(pluginContext.settings);
        db_1.initDatabase();
        passport_1.initPassport();
        index_1.initMiddleware();
        pluginContext.registerPolicy(auth_secure_policy_1.default);
        pluginContext.registerPolicy(jwt_auth_policy_1.default);
        pluginContext.registerPolicy(basic_auth_policy_1.default);
        pluginContext.registerPolicy(local_auth_policy_1.default);
        pluginContext.registerPolicy(session_auth_policy_1.default);
        pluginContext.registerGatewayRoute(auth_eg_1.default);
        pluginContext.registerGatewayRoute(auth_user_eg_1.default);
        pluginContext.registerGatewayRoute(google_oauth20_eg_1.default);
    },
    policies: ['auth-secure', 'jwt-auth', 'session-auth', 'local-auth'],
    schema: {
        $id: 'http://express-gateway.io/schemas/plugin/express-gateway-plugin-cas.json',
        type: 'object',
        properties: {
            DATABASE_URL: {
                type: 'string'
            },
            AUTH_HEADER: {
                type: 'string',
                default: 'auth-user'
            },
            ADMIN_KEY: {
                type: 'string',
                default: 'admin_key'
            },
            JWT_SECRET: {
                type: 'string',
                default: 'jwt_secret'
            },
            JWT_EXPIRATION_DELTA: {
                type: 'string'
            },
            JWT_REFRESH_EXPIRATION_DELTA: {
                type: 'string'
            },
            USER_MODEL_PATH: {
                type: 'string'
            },
            ADMIN_CORS: {
                type: 'object',
                properties: {
                    origin: {
                        type: ['string', 'boolean', 'array'],
                        items: { type: 'string' },
                        default: '*'
                    },
                    methods: {
                        type: ['string', 'array'],
                        items: { type: 'string' },
                        default: ['GET', 'HEAD', 'PUT', 'PATCH', 'POST', 'DELETE']
                    },
                    allowedHeaders: {
                        type: ['string', 'array'],
                        items: { type: 'string' }
                    },
                    exposedHeaders: {
                        type: 'array',
                        items: { type: 'string' }
                    },
                    credentials: {
                        type: 'boolean'
                    },
                    maxAge: {
                        type: 'integer'
                    },
                    optionsSuccessStatus: {
                        type: 'integer',
                        default: 204
                    },
                    preflightContinue: {
                        type: 'boolean',
                        default: false
                    }
                },
                default: {}
            }
        },
        required: ['DATABASE_URL']
    },
    options: {
        DATABASE_URL: {
            title: "User's database url",
            type: 'string',
            required: true
        }
    }
};
module.exports = plugin;
//# sourceMappingURL=manifest.js.map