"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const Sequelize = require("sequelize");
const user_util_1 = require("./../utils/user-util");
exports.initUserModel = (sequelize, userModelPath = null) => {
    let UserModel;
    if (userModelPath) {
        const path = path_1.resolve(process.cwd(), userModelPath);
        UserModel = sequelize.import(path);
    }
    else {
        const attributes = {
            username: { type: Sequelize.STRING, allowNull: false, unique: true },
            password: { type: Sequelize.STRING, allowNull: false },
            firstName: { type: Sequelize.STRING },
            lastName: { type: Sequelize.STRING },
            email: { type: Sequelize.STRING }
        };
        UserModel = sequelize.define('users', attributes);
    }
    UserModel.beforeUpdate(hashUserPassword);
    UserModel.beforeCreate(hashUserPassword);
    exports.User = UserModel;
    return UserModel;
};
const hashUserPassword = (user) => __awaiter(this, void 0, void 0, function* () {
    const previousPassword = user.previous('password');
    if (!previousPassword || !(yield user_util_1.comparePassword(user, user.previous('password')))) {
        user.password = yield user_util_1.hashPassword(user.password);
        return;
    }
});
//# sourceMappingURL=user-model.js.map