"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const authentication_1 = require("../middleware/authentication");
const user_model_1 = require("../models/user-model");
const middleware_1 = require("./../middleware");
const async_handler_1 = require("./../utils/async-handler");
const response_util_1 = require("./../utils/response-util");
const user_util_1 = require("./../utils/user-util");
exports.default = (gatewayExpressApp) => {
    gatewayExpressApp.options('/auth/user', middleware_1.corsMiddleware);
    gatewayExpressApp.options('/auth/user/*', middleware_1.corsMiddleware);
    gatewayExpressApp.get('/auth/user', middleware_1.corsMiddleware, authentication_1.apiKeyAuthorize, async_handler_1.asyncifyHandler((req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            const users = yield user_model_1.User.findAll();
            return res.json(user_util_1.getUserViews(users));
        }
        catch (error) {
            next(error);
        }
    })));
    gatewayExpressApp.get('/auth/user/:username', middleware_1.corsMiddleware, authentication_1.apiKeyAuthorize, async_handler_1.asyncifyHandler((req, res, next) => __awaiter(this, void 0, void 0, function* () {
        const username = req.params.username;
        try {
            const user = yield user_model_1.User.findOne({ where: { username } });
            if (!user) {
                return response_util_1.ResponseUtil.sendInvalidId(res);
            }
            return res.json(user_util_1.getUserView(user));
        }
        catch (error) {
            next(error);
        }
    })));
    gatewayExpressApp.post('/auth/user', middleware_1.corsMiddleware, middleware_1.jsonMiddleware, authentication_1.apiKeyAuthorize, async_handler_1.asyncifyHandler((req, res, next) => __awaiter(this, void 0, void 0, function* () {
        try {
            const user = yield user_model_1.User.create(Object.assign({}, req.body));
            return res.json(user_util_1.getUserView(user));
        }
        catch (error) {
            if (error.name === 'SequelizeUniqueConstraintError') {
                return response_util_1.ResponseUtil.sendDuplicateKeyError(res, 'Unique column is duplicated.', error.errors);
            }
            return response_util_1.ResponseUtil.sendValidationError(res, error.errors);
        }
    })));
    gatewayExpressApp.put('/auth/user/:username', middleware_1.corsMiddleware, middleware_1.jsonMiddleware, authentication_1.apiKeyAuthorize, async_handler_1.asyncifyHandler((req, res, next) => __awaiter(this, void 0, void 0, function* () {
        const username = req.params.username;
        try {
            const user = yield user_model_1.User.findOne({ where: { username } });
            if (!user) {
                return response_util_1.ResponseUtil.sendInvalidId(res);
            }
            const updatedUser = yield user.update(Object.assign({}, req.body));
            return res.json(user_util_1.getUserView(updatedUser));
        }
        catch (error) {
            if (error.name === 'SequelizeUniqueConstraintError') {
                return response_util_1.ResponseUtil.sendDuplicateKeyError(res, 'Unique column is duplicated.', error.errors);
            }
            return response_util_1.ResponseUtil.sendValidationError(res, error.errors);
        }
    })));
    gatewayExpressApp.delete('/auth/user/:username', middleware_1.corsMiddleware, authentication_1.apiKeyAuthorize, async_handler_1.asyncifyHandler((req, res, next) => __awaiter(this, void 0, void 0, function* () {
        const row = yield user_model_1.User.destroy({ where: { username: req.params.username } });
        if (row > 0) {
            return res.send('Success');
        }
        return response_util_1.ResponseUtil.sendInvalidId(res);
    })));
};
//# sourceMappingURL=auth-user-eg.js.map