"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const constant_1 = require("../config/constant");
const request_util_1 = require("../utils/request-util");
const request_util_2 = require("./request-util");
const response_util_1 = require("./response-util");
const user_util_1 = require("./user-util");
exports.getCommonAuthCallback = (actionParams, req, res, next) => {
    return (err, user, info) => {
        if (user) {
            request_util_1.setReqAuthUser(req, user);
            return next();
        }
        else if (request_util_2.getReqAuthUser(req)) {
            return next();
        }
        else if (err) {
            return next(err);
        }
        if (actionParams &&
            (actionParams.passThrough ||
                (actionParams.passThroughSafeMethod &&
                    _.includes(constant_1.SAFE_METHOD, req.method)))) {
            return next();
        }
        if (info && info.unauthorized) {
            return response_util_1.ResponseUtil.sendForbidden(res);
        }
        // Handle TokenExpiredError
        if (info && info.name === 'TokenExpiredError') {
            return response_util_1.ResponseUtil.sendTokenExpiredError(res);
        }
        return response_util_1.ResponseUtil.sendUnauthorized(res);
    };
};
exports.getRefreshTokenCallback = (req, res, next) => {
    return (err, user, info) => {
        if (err) {
            return next(err);
        }
        if (info.jwtPayload) {
            const token = user_util_1.generateAuthToken(user, info.jwtPayload.expiresIn);
            if (!token) {
                // Refresh is expired
                return response_util_1.ResponseUtil.sendRefreshExpiredError(res);
            }
            return res.json(Object.assign({}, token));
        }
        // Handle TokenExpiredError
        if (info && info.name === 'TokenExpiredError') {
            return response_util_1.ResponseUtil.sendTokenExpiredError(res);
        }
        return response_util_1.ResponseUtil.sendUnauthorized(res);
    };
};
//# sourceMappingURL=passport-util.js.map