"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const bcrypt = require("bcrypt");
const jwt = require("jsonwebtoken");
const ms = require("ms");
const config_1 = require("../config");
const index_1 = require("./../config/index");
const user_model_1 = require("./../models/user-model");
exports.getUserView = (user) => {
    const userView = user.toJSON();
    delete userView.password;
    return userView;
};
exports.getUserViews = (users) => {
    return users.map(user => {
        return exports.getUserView(user);
    });
};
exports.findUserByPayload = (payload) => __awaiter(this, void 0, void 0, function* () {
    const user = yield user_model_1.User.findOne({
        where: { username: payload.username }
    });
    if (user && user.password === payload.password) {
        return user;
    }
    return null;
});
exports.generateAuthToken = (user, refreshExpiresIn = null) => {
    const payload = {
        username: user.username,
        password: user.password
    };
    const tokenContainer = {};
    if (refreshExpiresIn) {
        if (refreshExpiresIn < Date.now()) {
            return null;
        }
        payload.expiresIn = refreshExpiresIn;
    }
    else if (index_1.JWT_REFRESH_EXPIRATION_DELTA) {
        payload.expiresIn = Date.now() + ms(index_1.JWT_REFRESH_EXPIRATION_DELTA);
    }
    const options = {};
    if (index_1.JWT_EXPIRATION_DELTA) {
        options.expiresIn = index_1.JWT_EXPIRATION_DELTA;
        tokenContainer.expiresIn = new Date(Date.now() + ms(index_1.JWT_EXPIRATION_DELTA));
    }
    tokenContainer.token = jwt.sign(payload, config_1.JWT_SECRET, options);
    return tokenContainer;
};
exports.hashPassword = (password) => __awaiter(this, void 0, void 0, function* () {
    const salt = yield bcrypt.genSalt(10);
    return yield bcrypt.hash(password, salt);
});
exports.comparePassword = (user, password) => {
    return bcrypt.compare(password, user.password);
};
//# sourceMappingURL=user-util.js.map